# AAS Job Register Downloader

The AAS Job register (https://jobregister.aas.org/) has a lot of cool jobs but these are a bit challenging to sift through.

This tries to collect some data from the site and tabulate it. I hope it helps you in your search!

## To use
```
pip install aas_job_register_downloader
download_aas_jobs
```
If you want the job descriptions to be added in the table:
```
download_aas_jobs -v
```
